Contribute: [contributing.md](https://github.com/clvrk/cocktail-wrapper/blob/master/contributing.md)
Docs: [Docs.md](https://github.com/clvrk/cocktail-wrapper/blob/master/Docs.md)

Alcohol endpoints such as: [link](www.thecocktaildb.com/api/json/v1/1/list.php?a=list) are not supported, completely useless.